
#line 3 "lex.gdb_result_.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer gdb_result__create_buffer
#define yy_delete_buffer gdb_result__delete_buffer
#define yy_flex_debug gdb_result__flex_debug
#define yy_init_buffer gdb_result__init_buffer
#define yy_flush_buffer gdb_result__flush_buffer
#define yy_load_buffer_state gdb_result__load_buffer_state
#define yy_switch_to_buffer gdb_result__switch_to_buffer
#define yyin gdb_result_in
#define yyleng gdb_result_leng
#define yylex gdb_result_lex
#define yylineno gdb_result_lineno
#define yyout gdb_result_out
#define yyrestart gdb_result_restart
#define yytext gdb_result_text
#define yywrap gdb_result_wrap
#define yyalloc gdb_result_alloc
#define yyrealloc gdb_result_realloc
#define yyfree gdb_result_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE gdb_result_restart(gdb_result_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t gdb_result_leng;

extern FILE *gdb_result_in, *gdb_result_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE gdb_result_lex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-gdb_result_lineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < gdb_result_leng; ++yyl )\
                    if ( gdb_result_text[yyl] == '\n' )\
                        --gdb_result_lineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gdb_result_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up gdb_result_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via gdb_result_restart()), so that the user can continue scanning by
	 * just pointing gdb_result_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when gdb_result_text is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t gdb_result_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow gdb_result_wrap()'s to do buffer switches
 * instead of setting up a fresh gdb_result_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void gdb_result_restart (FILE *input_file  );
void gdb_result__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE gdb_result__create_buffer (FILE *file,int size  );
void gdb_result__delete_buffer (YY_BUFFER_STATE b  );
void gdb_result__flush_buffer (YY_BUFFER_STATE b  );
void gdb_result_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void gdb_result_pop_buffer_state (void );

static void gdb_result_ensure_buffer_stack (void );
static void gdb_result__load_buffer_state (void );
static void gdb_result__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER gdb_result__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE gdb_result__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE gdb_result__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE gdb_result__scan_bytes (yyconst char *bytes,yy_size_t len  );

void *gdb_result_alloc (yy_size_t  );
void *gdb_result_realloc (void *,yy_size_t  );
void gdb_result_free (void *  );

#define yy_new_buffer gdb_result__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        gdb_result_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gdb_result__create_buffer(gdb_result_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        gdb_result_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gdb_result__create_buffer(gdb_result_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *gdb_result_in = (FILE *) 0, *gdb_result_out = (FILE *) 0;

typedef int yy_state_type;

extern int gdb_result_lineno;

int gdb_result_lineno = 1;

extern char *gdb_result_text;
#define yytext_ptr gdb_result_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up gdb_result_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	gdb_result_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 81
#define YY_END_OF_BUFFER 82
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[348] =
    {   0,
        0,    0,    0,    0,    0,    0,   82,   60,    1,    3,
        2,   58,   57,   60,    5,    4,   54,   52,   52,   52,
       60,   53,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   55,   56,   71,
       81,   70,   71,   80,   80,    1,    3,    0,    2,    7,
        7,    5,    0,    0,    5,    5,    0,    4,    4,    4,
       52,   52,   58,    0,   59,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,    0,   68,    0,

       69,   79,    0,    0,    7,    0,    7,    5,    6,    4,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   34,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,    0,    0,
        0,   62,   64,   65,   63,    0,    0,   73,   75,   76,
       74,    0,    7,    6,    6,   52,   25,   18,   52,   52,
       36,   35,   52,   52,   52,   24,   52,    8,   52,   52,
       12,   52,   52,   52,   49,   52,   52,   17,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   38,

       23,   52,   52,   52,    0,   61,   66,   67,    0,   77,
       78,    6,   52,   52,   26,   52,   52,   28,   52,   52,
       52,   11,   20,   52,   52,   19,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   16,
       52,   52,   30,   72,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   21,   52,   52,   52,   52,   52,
       48,   39,   52,   52,   52,   52,   52,   52,   29,   52,
       50,   52,   52,   52,   52,   52,   42,   52,   52,   52,
       52,   33,   32,   52,   52,    9,   52,   37,   52,   52,
       52,   52,   52,   27,   52,   52,   52,   41,   52,   52,

       22,   52,   52,   52,   52,   52,   51,   52,   10,   52,
       47,   52,   52,   52,   52,   52,   14,   52,   40,   52,
       52,   52,   52,   13,   52,   52,   46,   52,   52,   52,
       52,   52,   43,   52,   52,   52,   52,   52,   52,   44,
       52,   52,   15,   31,   52,   45,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    5,    6,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    7,    1,    8,    1,    1,    1,    1,    1,    1,
        1,    1,    9,   10,   11,   12,    1,   13,   14,   14,
       14,   14,   14,   14,   14,   15,   15,    1,    1,    1,
       16,    1,    1,    1,   17,   18,   17,   17,   19,   20,
       21,   21,   21,   21,   21,   22,   21,   21,   21,   21,
       21,   21,   21,   23,   24,   21,   21,   25,   21,   21,
        1,   26,    1,   27,   28,    1,   29,   30,   31,   32,

       33,   34,   35,   36,   37,   38,   39,   40,   41,   42,
       43,   44,   21,   45,   46,   47,   48,   49,   50,   51,
       52,   21,   53,    1,   54,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[55] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        2,    1,    3,    3,    3,    1,    3,    3,    3,    3,
        2,    2,    2,    2,    2,    1,    1,    2,    3,    3,
        3,    3,    3,    3,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    1,    1
    } ;

static yyconst flex_int16_t yy_base[352] =
    {   0,
        0,    0,   52,   53,   54,   55,  474,  475,   60,  475,
       66,  475,  475,   61,   70,  110,  475,    0,  428,   51,
      464,  475,   54,   48,   54,   59,   53,   60,   77,  429,
       74,   83,  436,   82,  422,   83,  439,  455,  475,  475,
      475,  475,  125,  475,  118,  150,  475,  157,  163,  158,
        0,   76,  169,  186,   89,  153,    0,    0,  155,  154,
        0,  433,  475,  457,  475,  432,  428,  105,  418,  429,
      111,  418,  412,  412,  415,  414,  410,  417,  424,  410,
      405,  405,  403,  399,  416,  405,  395,  416,  402,  408,
      112,  399,  161,  395,  398,  394,  165,  425,  475,  172,

      193,  475,  199,  207,  475,  213,  217,  475,  212,  475,
      407,  390,  388,  396,  404,  384,  378,  387,  388,  385,
      397,  381,  391,  394,  379,  374,  379,  388,  390,    0,
      370,  383,  386,  381,  385,  178,  381,  365,  364,  372,
      366,  376,  362,  372,  371,  370,  354,  171,  389,  236,
      203,  475,  475,  475,  475,  240,  207,  475,  475,  475,
      475,  248,  251,  219,  234,  361,  366,    0,  361,  360,
        0,    0,  361,  363,  361,    0,  353,    0,  351,  346,
        0,  357,  378,  347,    0,  347,  346,    0,  216,  342,
      341,  347,  349,  338,  334,  342,  339,  333,  347,    0,

        0,  342,  345,  343,  318,  475,  475,  475,  255,  475,
      475,  475,  327,  324,    0,  327,  335,  322,  335,  336,
      327,    0,    0,  321,  319,    0,  315,  324,  311,  318,
      307,  319,  308,  312,  306,  310,  340,  317,  317,    0,
      318,  309,  475,  475,  303,  299,  298,  303,  309,  294,
      288,  308,  309,  292,    0,  299,  294,  288,  287,  292,
        0,    0,  298,  295,  300,  296,  316,  286,    0,  288,
        0,  282,  286,  280,  288,  284,    0,  278,  285,  277,
      288,    0,    0,  283,  269,    0,  268,    0,  277,  278,
      268,  263,  262,    0,  275,  269,  272,    0,  272,  272,

        0,  291,  266,  255,  244,  242,    0,  241,    0,  245,
        0,  241,  248,  241,  236,  238,    0,  257,    0,  232,
      245,  240,  247,    0,  227,  243,    0,  228,  219,  214,
      201,  194,    0,  185,  163,  143,  147,  129,  103,    0,
      112,  109,    0,    0,   72,    0,  475,  291,  294,  296,
       90
    } ;

static yyconst flex_int16_t yy_def[352] =
    {   0,
      347,    1,  348,  348,  349,  349,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  350,  350,  350,
      347,  347,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
       50,   15,  347,  347,  347,  347,  351,   16,  347,  347,
      350,  350,  347,  347,  347,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  347,  347,  347,

      347,  347,  347,  347,  347,  347,  347,  347,  351,  347,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,

      350,  350,  350,  350,  347,  347,  347,  347,  347,  347,
      347,  347,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  347,  347,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,

      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,    0,  347,  347,  347,
      347
    } ;

static yyconst flex_int16_t yy_nxt[530] =
    {   0,
        8,    9,   10,   11,   11,   11,    9,   12,    8,   13,
        8,   14,   15,   16,   16,   17,   18,   19,   18,   18,
       18,   20,   18,   18,   18,   21,   22,   18,   23,   24,
       25,   26,   27,   28,   18,   29,   30,   18,   18,   31,
       18,   32,   33,   18,   34,   35,   36,   18,   37,   18,
       18,   18,   38,   39,   41,   41,   41,   41,   63,   42,
       42,   46,   47,   48,   48,   48,   46,   48,   47,   49,
       49,   49,   48,   50,   50,   50,   64,   43,   43,   45,
       45,   51,   52,   52,   53,   66,   69,   73,   54,   71,
       70,   55,  109,   56,   57,   74,   72,   77,   67,   68,

      347,   75,   54,   78,   79,   81,   84,   80,   82,   55,
       76,   86,  108,  346,   91,   87,   85,   56,   94,   95,
       57,   51,   58,   58,   58,  102,  347,   88,   54,   92,
       89,   59,   99,   60,   96,  114,  108,  100,  100,  118,
      139,  345,   54,  103,  344,  115,  140,  119,  343,   59,
      101,   46,   47,   48,   48,   48,   46,   60,   48,   47,
       48,   48,   48,   48,   48,   47,   49,   49,   49,   48,
       50,   50,   50,  342,  108,  110,  104,  105,  110,  105,
       51,   53,   53,   53,  150,  150,  341,   54,  340,  142,
      104,  105,  108,  110,  106,  339,  106,  105,  107,  107,

      107,   54,  110,  143,  147,  100,  100,  203,  190,  148,
      207,  156,  156,  204,  210,  162,  338,  162,  151,  163,
      163,  163,  191,  337,  157,  107,  107,  107,  208,  107,
      107,  107,  211,  164,  152,  165,  105,  153,  105,  154,
      158,  155,  212,  159,  336,  160,  228,  161,  206,  206,
      105,  164,  209,  209,  335,  212,  105,  229,  334,  165,
      163,  163,  163,  163,  163,  163,  212,  244,  244,  333,
      105,  332,  105,  212,  331,  330,  329,  328,  327,  326,
      325,  324,  323,  322,  105,  321,  320,  319,  318,  317,
      105,   40,   40,   40,   44,   44,   44,   61,   61,  316,

      315,  314,  313,  312,  311,  310,  309,  308,  307,  306,
      305,  304,  303,  302,  301,  300,  299,  298,  297,  296,
      295,  294,  293,  292,  291,  290,  289,  288,  287,  286,
      285,  284,  283,  282,  281,  280,  279,  278,  277,  276,
      275,  274,  273,  272,  271,  270,  269,  268,  267,  266,
      265,  264,  263,  262,  261,  260,  259,  258,  257,  256,
      255,  254,  253,  252,  251,  250,  249,  248,  247,  246,
      245,  243,  242,  241,  240,  239,  238,  237,  236,  235,
      234,  233,  232,  231,  230,  227,  226,  225,  224,  223,
      222,  221,  220,  219,  218,  217,  216,  215,  214,  213,

      205,  202,  201,  200,  199,  198,  197,  196,  195,  194,
      193,  192,  189,  188,  187,  186,  185,  184,  183,  182,
      181,  180,  179,  178,  177,  176,  175,  174,  173,  172,
      171,  170,  169,  168,  167,  166,  149,  146,  145,  144,
      141,  138,  137,  136,  135,  134,  133,  132,  131,  130,
      129,  128,  127,  126,  125,  124,  123,  122,  121,  120,
      117,  116,  113,  112,   65,  111,   98,   97,   93,   90,
       83,   65,   62,  347,    7,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,

      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347
    } ;

static yyconst flex_int16_t yy_chk[530] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    4,    5,    6,   20,    3,
        4,    9,    9,    9,    9,    9,    9,   11,   11,   11,
       11,   11,   11,   14,   14,   14,   20,    3,    4,    5,
        6,   15,   15,   15,   15,   23,   24,   26,   15,   25,
       24,   15,  351,   15,   15,   26,   25,   27,   23,   23,

       52,   26,   15,   27,   28,   29,   31,   28,   29,   15,
       26,   32,   55,  345,   34,   32,   31,   15,   36,   36,
       15,   16,   16,   16,   16,   45,   52,   32,   16,   34,
       32,   16,   43,   16,   36,   68,   55,   43,   43,   71,
       91,  342,   16,   45,  341,   68,   91,   71,  339,   16,
       43,   46,   46,   46,   46,   46,   46,   16,   48,   48,
       48,   48,   48,   48,   49,   49,   49,   49,   49,   49,
       50,   50,   50,  338,   56,   60,   50,   50,   59,   50,
       53,   53,   53,   53,  100,  100,  337,   53,  336,   93,
       50,   50,   56,   60,   54,  335,   54,   50,   54,   54,

       54,   53,   59,   93,   97,  101,  101,  148,  136,   97,
      151,  103,  103,  148,  157,  104,  334,  104,  101,  104,
      104,  104,  136,  332,  103,  106,  106,  106,  151,  107,
      107,  107,  157,  109,  101,  109,  107,  101,  107,  101,
      103,  101,  164,  103,  331,  103,  189,  103,  150,  150,
      107,  109,  156,  156,  330,  165,  107,  189,  329,  109,
      162,  162,  162,  163,  163,  163,  164,  209,  209,  328,
      163,  326,  163,  165,  325,  323,  322,  321,  320,  318,
      316,  315,  314,  313,  163,  312,  310,  308,  306,  305,
      163,  348,  348,  348,  349,  349,  349,  350,  350,  304,

      303,  302,  300,  299,  297,  296,  295,  293,  292,  291,
      290,  289,  287,  285,  284,  281,  280,  279,  278,  276,
      275,  274,  273,  272,  270,  268,  267,  266,  265,  264,
      263,  260,  259,  258,  257,  256,  254,  253,  252,  251,
      250,  249,  248,  247,  246,  245,  242,  241,  239,  238,
      237,  236,  235,  234,  233,  232,  231,  230,  229,  228,
      227,  225,  224,  221,  220,  219,  218,  217,  216,  214,
      213,  205,  204,  203,  202,  199,  198,  197,  196,  195,
      194,  193,  192,  191,  190,  187,  186,  184,  183,  182,
      180,  179,  177,  175,  174,  173,  170,  169,  167,  166,

      149,  147,  146,  145,  144,  143,  142,  141,  140,  139,
      138,  137,  135,  134,  133,  132,  131,  129,  128,  127,
      126,  125,  124,  123,  122,  121,  120,  119,  118,  117,
      116,  115,  114,  113,  112,  111,   98,   96,   95,   94,
       92,   90,   89,   88,   87,   86,   85,   84,   83,   82,
       81,   80,   79,   78,   77,   76,   75,   74,   73,   72,
       70,   69,   67,   66,   64,   62,   38,   37,   35,   33,
       30,   21,   19,    7,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,

      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[82] =
    {   0,
0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int gdb_result__flex_debug;
int gdb_result__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *gdb_result_text;
/* Included code before lex code */
#include "string"
#include "gdb_result_parser.h"
#include <vector>
#include <sstream>

#define YYSTYPE std::string

static std::vector<YY_BUFFER_STATE> gs_bufferStack;
static std::string                  gs_string;
static bool                         gs_ascii;
static bool                         gs_want_whitespace = false;

std::string gdb_result_string;
bool setGdbLexerInput(const std::string &in, bool ascii);

void gdb_result_lex_clean();
void gdb_result_less(int count);

extern std::string gdb_result_lval;

#define RETURN_VAL(x) {\
					gdb_result_string = gdb_result_text;\
					gdb_result_lval   = gdb_result_text;\
					return(x);}

#define RETURN_ESCAPED_STRING(x) {\
					gdb_result_string = gdb_result_text;\
					std::string str;\
					str = gdb_result_string.substr(1);\
					gdb_result_string = str;\
					gdb_result_lval = str;\
					return(x);}
/**
 * Some basic regexes
 */

#define INITIAL 0
#define string_state 1
#define esc_string_state 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif
    
#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int gdb_result_lex_destroy (void );

int gdb_result_get_debug (void );

void gdb_result_set_debug (int debug_flag  );

YY_EXTRA_TYPE gdb_result_get_extra (void );

void gdb_result_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *gdb_result_get_in (void );

void gdb_result_set_in  (FILE * in_str  );

FILE *gdb_result_get_out (void );

void gdb_result_set_out  (FILE * out_str  );

yy_size_t gdb_result_get_leng (void );

char *gdb_result_get_text (void );

int gdb_result_get_lineno (void );

void gdb_result_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int gdb_result_wrap (void );
#else
extern int gdb_result_wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( gdb_result_text, gdb_result_leng, 1, gdb_result_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( gdb_result_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( gdb_result_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, gdb_result_in))==0 && ferror(gdb_result_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(gdb_result_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int gdb_result_lex (void);

#define YY_DECL int gdb_result_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after gdb_result_text and gdb_result_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! gdb_result_in )
			gdb_result_in = stdin;

		if ( ! gdb_result_out )
			gdb_result_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			gdb_result_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				gdb_result__create_buffer(gdb_result_in,YY_BUF_SIZE );
		}

		gdb_result__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of gdb_result_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 348 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 475 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < gdb_result_leng; ++yyl )
				if ( gdb_result_text[yyl] == '\n' )
					   
    gdb_result_lineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
{if(gs_want_whitespace) RETURN_VAL((int)' '); }
	YY_BREAK
case 2:
YY_RULE_SETUP
{if(gs_want_whitespace) RETURN_VAL((int)' '); }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
{if(gs_want_whitespace) RETURN_VAL((int)'\n'); }
	YY_BREAK
case 4:
YY_RULE_SETUP
{RETURN_VAL(GDB_INTEGER);}
	YY_BREAK
case 5:
YY_RULE_SETUP
{RETURN_VAL(GDB_OCTAL);}
	YY_BREAK
case 6:
YY_RULE_SETUP
{RETURN_VAL(GDB_HEX);}
	YY_BREAK
case 7:
YY_RULE_SETUP
{RETURN_VAL(GDB_FLOAT);}
	YY_BREAK
case 8:
YY_RULE_SETUP
{RETURN_VAL(GDB_DONE);}
	YY_BREAK
case 9:
YY_RULE_SETUP
{RETURN_VAL(GDB_RUNNING);}
	YY_BREAK
case 10:
YY_RULE_SETUP
{RETURN_VAL(GDB_CONNECTED);}
	YY_BREAK
case 11:
YY_RULE_SETUP
{RETURN_VAL(GDB_ERROR);}
	YY_BREAK
case 12:
YY_RULE_SETUP
{RETURN_VAL(GDB_EXIT);}
	YY_BREAK
case 13:
YY_RULE_SETUP
{RETURN_VAL(GDB_STACK_ARGS);}
	YY_BREAK
case 14:
YY_RULE_SETUP
{RETURN_VAL(GDB_VARIABLES);}
	YY_BREAK
case 15:
YY_RULE_SETUP
{RETURN_VAL(GDB_REGISTER_NAMES);}
	YY_BREAK
case 16:
YY_RULE_SETUP
{RETURN_VAL(GDB_VALUE);}
	YY_BREAK
case 17:
YY_RULE_SETUP
{RETURN_VAL(GDB_NAME);}
	YY_BREAK
case 18:
YY_RULE_SETUP
{RETURN_VAL(GDB_ARGS);}
	YY_BREAK
case 19:
YY_RULE_SETUP
{RETURN_VAL(GDB_LEVEL);}
	YY_BREAK
case 20:
YY_RULE_SETUP
{RETURN_VAL(GDB_FRAME);}
	YY_BREAK
case 21:
YY_RULE_SETUP
{RETURN_VAL(GDB_LOCALS);}
	YY_BREAK
case 22:
YY_RULE_SETUP
{RETURN_VAL(GDB_NUMCHILD);}
	YY_BREAK
case 23:
YY_RULE_SETUP
{RETURN_VAL(GDB_TYPE);}
	YY_BREAK
case 24:
YY_RULE_SETUP
{RETURN_VAL(GDB_DATA);}
	YY_BREAK
case 25:
YY_RULE_SETUP
{RETURN_VAL(GDB_ADDR);}
	YY_BREAK
case 26:
YY_RULE_SETUP
{RETURN_VAL(GDB_ASCII);}
	YY_BREAK
case 27:
YY_RULE_SETUP
{RETURN_VAL(GDB_CHILDREN);}
	YY_BREAK
case 28:
YY_RULE_SETUP
{RETURN_VAL(GDB_CHILD);}
	YY_BREAK
case 29:
YY_RULE_SETUP
{RETURN_VAL(GDB_VAROBJ);}
	YY_BREAK
case 30:
YY_RULE_SETUP
{RETURN_VAL(GDB_MORE);}
	YY_BREAK
case 31:
YY_RULE_SETUP
{RETURN_VAL(GDB_BREAKPOINT_TABLE);}
	YY_BREAK
case 32:
YY_RULE_SETUP
{RETURN_VAL(GDB_NR_ROWS);}
	YY_BREAK
case 33:
YY_RULE_SETUP
{RETURN_VAL(GDB_NR_COLS);}
	YY_BREAK
case 34:
YY_RULE_SETUP
{RETURN_VAL(GDB_HDR);}
	YY_BREAK
case 35:
YY_RULE_SETUP
{RETURN_VAL(GDB_BODY);}
	YY_BREAK
case 36:
YY_RULE_SETUP
{RETURN_VAL(GDB_BKPT);}
	YY_BREAK
case 37:
YY_RULE_SETUP
{RETURN_VAL(GDB_STOPPED);}
	YY_BREAK
case 38:
YY_RULE_SETUP
{RETURN_VAL(GDB_TIME);}
	YY_BREAK
case 39:
YY_RULE_SETUP
{RETURN_VAL(GDB_REASON);}
	YY_BREAK
case 40:
YY_RULE_SETUP
{RETURN_VAL(GDB_CHANGELIST);}
	YY_BREAK
case 41:
YY_RULE_SETUP
{RETURN_VAL(GDB_HAS_MORE);}
	YY_BREAK
case 42:
YY_RULE_SETUP
{RETURN_VAL(GDB_DYNAMIC);}
	YY_BREAK
case 43:
YY_RULE_SETUP
{RETURN_VAL(GDB_NEW_CHILDREN);}
	YY_BREAK
case 44:
YY_RULE_SETUP
{RETURN_VAL(GDB_THREAD_GROUPS);}
	YY_BREAK
case 45:
YY_RULE_SETUP
{RETURN_VAL(GDB_NEW_NUM_CHILDREN);}
	YY_BREAK
case 46:
YY_RULE_SETUP
{RETURN_VAL(GDB_DISPLAYHINT);}
	YY_BREAK
case 47:
YY_RULE_SETUP
{RETURN_VAL(GDB_FUNC_NAME);}
	YY_BREAK
case 48:
YY_RULE_SETUP
{RETURN_VAL(GDB_OFFSET);}
	YY_BREAK
case 49:
YY_RULE_SETUP
{RETURN_VAL(GDB_INSTRUCTION);}
	YY_BREAK
case 50:
YY_RULE_SETUP
{RETURN_VAL(GDB_ADDRESS);}
	YY_BREAK
case 51:
YY_RULE_SETUP
{RETURN_VAL(GDB_ASM_INSTS);}
	YY_BREAK
case 52:
YY_RULE_SETUP
{RETURN_VAL(GDB_IDENTIFIER);}
	YY_BREAK
case 53:
YY_RULE_SETUP
{RETURN_VAL((int)*gdb_result_text);}
	YY_BREAK
case 54:
YY_RULE_SETUP
{RETURN_VAL((int)*gdb_result_text);}
	YY_BREAK
case 55:
YY_RULE_SETUP
{RETURN_VAL((int)*gdb_result_text);}
	YY_BREAK
case 56:
YY_RULE_SETUP
{RETURN_VAL((int)*gdb_result_text);}
	YY_BREAK
case 57:
YY_RULE_SETUP
{RETURN_VAL((int)*gdb_result_text);}
	YY_BREAK
case 58:
YY_RULE_SETUP
{BEGIN (string_state); gs_string = "\"";}
	YY_BREAK
case 59:
YY_RULE_SETUP
{BEGIN (esc_string_state); gs_string = "\"";}
	YY_BREAK
case 60:
YY_RULE_SETUP
{RETURN_VAL((int)*gdb_result_text);}
	YY_BREAK
case 61:
YY_RULE_SETUP
{
	if(gs_ascii) {
		unsigned int number(0);
		std::stringstream s;
		s << std::oct << gdb_result_text+2;
		s >> number;

		if(number) {
			gs_string += (unsigned char)number;
		}
	} else {
		gs_string += gdb_result_text;
	}
}
	YY_BREAK
case 62:
YY_RULE_SETUP
{ gs_string += "\\n"; }
	YY_BREAK
case 63:
YY_RULE_SETUP
{ gs_string += "\\v"; }
	YY_BREAK
case 64:
YY_RULE_SETUP
{ gs_string += "\\r"; }
	YY_BREAK
case 65:
YY_RULE_SETUP
{ gs_string += "\\t"; }
	YY_BREAK
case 66:
YY_RULE_SETUP
{ gs_string += "\\\""; }
	YY_BREAK
case 67:
YY_RULE_SETUP
{ gs_string += "\\"; }
	YY_BREAK
case 68:
YY_RULE_SETUP
{ gs_string += "\\\"";}
	YY_BREAK
case 69:
YY_RULE_SETUP
{ gs_string += "\\";}
	YY_BREAK
case 70:
YY_RULE_SETUP
{
	gs_string += "\"";
	gdb_result_string = gs_string;
	gdb_result_lval   = gdb_result_string;
	gs_string.clear();
	BEGIN (0);
	return GDB_STRING;
}
	YY_BREAK
case 71:
YY_RULE_SETUP
{ gs_string += gdb_result_text; }
	YY_BREAK
case 72:
YY_RULE_SETUP
{
	if(gs_ascii) {
		unsigned int number(0);
		std::stringstream s;
		s << std::oct << gdb_result_text+2;
		s >> number;

		if(number) {
			gs_string += (unsigned char)number;
		}
	} else {
		gs_string += gdb_result_text;
	}
}
	YY_BREAK
case 73:
YY_RULE_SETUP
{ gs_string += "\\n"; }
	YY_BREAK
case 74:
YY_RULE_SETUP
{ gs_string += "\\v"; }
	YY_BREAK
case 75:
YY_RULE_SETUP
{ gs_string += "\\r"; }
	YY_BREAK
case 76:
YY_RULE_SETUP
{ gs_string += "\\t"; }
	YY_BREAK
case 77:
YY_RULE_SETUP
{ gs_string += "\\\""; }
	YY_BREAK
case 78:
YY_RULE_SETUP
{ gs_string += "\\"; }
	YY_BREAK
case 79:
YY_RULE_SETUP
{
	gs_string += "\"";
	gdb_result_string = gs_string;
	gdb_result_lval   = gdb_result_string;
	gs_string.clear();
	BEGIN (0);
	return GDB_ESCAPED_STRING;
}
	YY_BREAK
case 80:
YY_RULE_SETUP
{ gs_string += gdb_result_text; }
	YY_BREAK
case 81:
YY_RULE_SETUP
ECHO;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(string_state):
case YY_STATE_EOF(esc_string_state):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed gdb_result_in at a new source and called
			 * gdb_result_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = gdb_result_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( gdb_result_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * gdb_result_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of gdb_result_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					gdb_result_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			gdb_result_restart(gdb_result_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) gdb_result_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 348 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 348 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 347);

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up gdb_result_text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --gdb_result_lineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					gdb_result_restart(gdb_result_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( gdb_result_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve gdb_result_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    gdb_result_lineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void gdb_result_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        gdb_result_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            gdb_result__create_buffer(gdb_result_in,YY_BUF_SIZE );
	}

	gdb_result__init_buffer(YY_CURRENT_BUFFER,input_file );
	gdb_result__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void gdb_result__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		gdb_result_pop_buffer_state();
	 *		gdb_result_push_buffer_state(new_buffer);
     */
	gdb_result_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	gdb_result__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (gdb_result_wrap()) processing, but the only time this flag
	 * is looked at is after gdb_result_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void gdb_result__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	gdb_result_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE gdb_result__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) gdb_result_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gdb_result__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) gdb_result_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in gdb_result__create_buffer()" );

	b->yy_is_our_buffer = 1;

	gdb_result__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with gdb_result__create_buffer()
 * 
 */
    void gdb_result__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		gdb_result_free((void *) b->yy_ch_buf  );

	gdb_result_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a gdb_result_restart() or at EOF.
 */
    static void gdb_result__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	gdb_result__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then gdb_result__init_buffer was _probably_
     * called from gdb_result_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void gdb_result__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		gdb_result__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void gdb_result_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	gdb_result_ensure_buffer_stack();

	/* This block is copied from gdb_result__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from gdb_result__switch_to_buffer. */
	gdb_result__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void gdb_result_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	gdb_result__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		gdb_result__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void gdb_result_ensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)gdb_result_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gdb_result_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)gdb_result_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gdb_result_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE gdb_result__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) gdb_result_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gdb_result__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	gdb_result__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to gdb_result_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       gdb_result__scan_bytes() instead.
 */
YY_BUFFER_STATE gdb_result__scan_string (yyconst char * yystr )
{
    
	return gdb_result__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to gdb_result_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE gdb_result__scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) gdb_result_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in gdb_result__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = gdb_result__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in gdb_result__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	// exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gdb_result_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		gdb_result_text[gdb_result_leng] = (yy_hold_char); \
		(yy_c_buf_p) = gdb_result_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		gdb_result_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int gdb_result_get_lineno  (void)
{
        
    return gdb_result_lineno;
}

/** Get the input stream.
 * 
 */
FILE *gdb_result_get_in  (void)
{
        return gdb_result_in;
}

/** Get the output stream.
 * 
 */
FILE *gdb_result_get_out  (void)
{
        return gdb_result_out;
}

/** Get the length of the current token.
 * 
 */
yy_size_t gdb_result_get_leng  (void)
{
        return gdb_result_leng;
}

/** Get the current token.
 * 
 */

char *gdb_result_get_text  (void)
{
        return gdb_result_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void gdb_result_set_lineno (int  line_number )
{
    
    gdb_result_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see gdb_result__switch_to_buffer
 */
void gdb_result_set_in (FILE *  in_str )
{
        gdb_result_in = in_str ;
}

void gdb_result_set_out (FILE *  out_str )
{
        gdb_result_out = out_str ;
}

int gdb_result_get_debug  (void)
{
        return gdb_result__flex_debug;
}

void gdb_result_set_debug (int  bdebug )
{
        gdb_result__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from gdb_result_lex_destroy(), so don't allocate here.
     */

    /* We do not touch gdb_result_lineno unless the option is enabled. */
    gdb_result_lineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    gdb_result_in = stdin;
    gdb_result_out = stdout;
#else
    gdb_result_in = (FILE *) 0;
    gdb_result_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * gdb_result_lex_init()
     */
    return 0;
}

/* gdb_result_lex_destroy is for both reentrant and non-reentrant scanners. */
int gdb_result_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		gdb_result__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		gdb_result_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	gdb_result_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * gdb_result_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *gdb_result_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *gdb_result_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void gdb_result_free (void * ptr )
{
	free( (char *) ptr );	/* see gdb_result_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

/*******************************************************************/
void gdb_result_lex_clean()
{
	gdb_result__flush_buffer(YY_CURRENT_BUFFER);
	gdb_result__delete_buffer(YY_CURRENT_BUFFER);
	gdb_result_lineno = 1;
	gs_ascii = false;
	gs_want_whitespace = false;
}

bool setGdbLexerInput(const std::string &in, bool ascii, bool wantWhitespace) {
	BEGIN INITIAL;
	gs_ascii = ascii;
	gs_want_whitespace = wantWhitespace;
	gdb_result__scan_string(in.c_str());
	return true;
}

int gdb_result_wrap(){
	return 1;
}

void gdb_result_less(int count){
	yyless(count);
}

void gdb_result_push_buffer(const std::string &new_input){
	// keep current buffer state
	gs_bufferStack.push_back(YY_CURRENT_BUFFER);

	// create new buffer and use it
	gdb_result__switch_to_buffer(gdb_result__scan_string(new_input.c_str()) );
}

void gdb_result_pop_buffer(){
	// clean current buffer
	gdb_result__delete_buffer(YY_CURRENT_BUFFER);

	// create new buffer and use it
	gdb_result__switch_to_buffer(gs_bufferStack.back() );
	gs_bufferStack.pop_back();
}

void gdb_result_error(const char* msg)
{
}

